@@ -18,19 +18,19 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/client-go/kubernetes"
 
-	ctlapp "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/app"
-	ctlcap "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/clusterapply"
-	cmdcore "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/core"
-	cmdtools "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/tools"
-	ctlconf "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/config"
-	ctldiff "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diff"
-	ctldgraph "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diffgraph"
-	ctldiffui "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/diffui"
-	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/logger"
-	ctllogs "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/logs"
-	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/preflight"
-	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
-	ctlresm "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resourcesmisc"
+	ctlapp "carvel.dev/kapp/pkg/kapp/app"
+	ctlcap "carvel.dev/kapp/pkg/kapp/clusterapply"
+	cmdcore "carvel.dev/kapp/pkg/kapp/cmd/core"
+	cmdtools "carvel.dev/kapp/pkg/kapp/cmd/tools"
+	ctlconf "carvel.dev/kapp/pkg/kapp/config"
+	ctldiff "carvel.dev/kapp/pkg/kapp/diff"
+	ctldgraph "carvel.dev/kapp/pkg/kapp/diffgraph"
+	ctldiffui "carvel.dev/kapp/pkg/kapp/diffui"
+	"carvel.dev/kapp/pkg/kapp/logger"
+	ctllogs "carvel.dev/kapp/pkg/kapp/logs"
+	"carvel.dev/kapp/pkg/kapp/preflight"
+	ctlres "carvel.dev/kapp/pkg/kapp/resources"
+	ctlresm "carvel.dev/kapp/pkg/kapp/resourcesmisc"
 )
 
 const (
