@@ -4,8 +4,8 @@
 package serviceaccount
 
 import (
+	cmdcore "carvel.dev/kapp/pkg/kapp/cmd/core"
 	"github.com/spf13/cobra"
-	cmdcore "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/cmd/core"
 )
 
 func NewCmd() *cobra.Command {
